#!/bin/bash

echo "--------------------------------------------------------"
echo "DeckMania StreamDeck Blender: Install addon to Blender"
echo "--------------------------------------------------------"
echo

# Define paths
source="$HOME/Library/Application Support/com.elgato.StreamDeck/Plugins/com.deckmania.blender.sdPlugin/deckmania_streamdeck_blender"
blenderAddonsFolder="$HOME/Library/Application Support/Blender"

# Check if the source folder exists
if [ ! -d "$source" ]; then
    echo "The folder $source was not found. Please verify if the plugin is installed in StreamDeck."
    exit 1
fi

# Check if the Blender Addons folder exists
if [ ! -d "$blenderAddonsFolder" ]; then
    echo "The folder $blenderAddonsFolder was not found. Please verify if Blender is installed."
    exit 1
fi

# Loop through Blender versions
for versionDir in "$blenderAddonsFolder"/*; do
    if [ -d "$versionDir" ]; then
        folderName=$(basename "$versionDir")
        target="$versionDir/scripts/addons/deckmania_streamdeck_blender"

        # Extract the major and minor version numbers
        major=$(echo "$folderName" | cut -d '.' -f 1)
        minor=$(echo "$folderName" | cut -d '.' -f 2)

        versionValid=0

        # Check if version is valid (major >= 4 and minor >= 3 for Blender 4.x versions)
        if [ -n "$major" ] && [ "$major" -ge 4 ]; then
            if [ -n "$minor" ] && [ "$minor" -ge 3 ]; then
                versionValid=1
            fi
        fi

        if [ "$versionValid" -eq 1 ]; then
            # Check if the scripts/addons directory exists, if not create it
            if [ ! -d "$versionDir/scripts" ]; then
                echo "Creating \scripts directory in $versionDir..."
                mkdir "$versionDir/scripts"
            fi
            if [ ! -d "$versionDir/scripts/addons" ]; then
                echo "Creating \addons directory in $versionDir/scripts..."
                mkdir "$versionDir/scripts/addons"
            fi

            # Ask user if they want to install the addon
            read -p "Do you want to add the add-on to Blender version $major.$minor? (Y/N): " userChoice

            if [[ "$userChoice" =~ ^[Yy]$ ]]; then
                if [ -d "$target" ]; then
                    echo "The target folder already exists: $target"
                    echo
                else
                    echo "Creating symbolic link: $target"
                    ln -s "$source" "$target"
                    echo
                fi
            else
                echo "Skipping Blender version $major.$minor."
                echo
            fi
        else
            echo "Skipping unsupported Blender version $major.$minor."
            echo
        fi
    fi
done
